@@ -144,27 +144,6 @@ class DesktopScreensaverSettings(ScreensaverSettings):
         self.name = name
 
     def load_from_file(self, filename):
-        if self.name == "xfce-blank":
-            self.valid = True
-
-            self.options = self.parse_internal()
-            self.label = _("Blank screen")
-            comment = _("Powered by Display Power Management Signaling (DPMS),\n"
-                        "Xfce Screensaver can automatically suspend your displays\n"
-                        "to save power.\n\n"
-                        "Xfce Power Manager and other applications also manage\n"
-                        "DPMS settings. If the settings here won't work, make sure\n"
-                        "display power management wasn't disabled there.\n"
-                        "If your displays are powering off at different\n"
-                        "intervals, be sure to check for conflicting settings.")
-            self.arguments = []
-            self.description = comment
-
-            if self.options:
-                self.configurable = True
-
-            return True
-
         if not os.path.exists(filename):
             return False
 
@@ -194,15 +173,6 @@ class DesktopScreensaverSettings(ScreensaverSettings):
 
     def parse_internal(self):
         options = OrderedDict()
-        if self.name == "xfce-blank":
-            options["dpms-sleep-after"] = {'id': 'dpms-sleep-after', 'type': 'slider',
-                                           'label': _("After blanking, put display to sleep after:"),
-                                           'default': 5, 'low': 0, 'high': 60, 'step': 1,
-                                           'low-label': _("Never"), 'high-label': _("60 seconds")}
-            options["dpms-off-after"] = {'id': 'dpms-off-after', 'type': 'slider',
-                                         'label': _("After sleeping, switch display off after:"),
-                                         'default': 15, 'low': 0, 'high': 60, 'step': 1,
-                                         'low-label': _("Never"), 'high-label': _("60 minutes")}
         if self.name == "xfce-floaters":
             options["number-of-images"] = {'id': 'number-of-images', 'type': 'spinbutton',
                                            'label': _("Max number of images"), 'argument': '-n %',
@@ -470,24 +440,24 @@ class ConfigurationWindow(Gtk.Window):
             else:
                 active = self.get_boolean(opt['id'], default)
 
-            widget.set_active(active)
             widget.connect("toggled", self.on_checkbutton_toggle, opt["id"])
+            widget.set_active(active)
         elif opt["type"] == "file":
             widget = Gtk.FileChooserButton(
                 title=opt["label"], action=Gtk.FileChooserAction.OPEN)
             filename = self.get_string(opt["id"], "")
             widget.set_current_folder("~")
-            widget.set_filename(filename)
             widget.connect("selection-changed",
                            self.on_file_changed, opt["id"])
+            widget.set_filename(filename)
         elif opt["type"] == "folder":
             widget = Gtk.FileChooserButton(
                 title=opt["label"], action=Gtk.FileChooserAction.SELECT_FOLDER)
             folder = self.get_string(opt["id"], opt["default"])
             widget.set_current_folder(folder)
-            widget.set_filename(folder)
             widget.connect("selection-changed",
                            self.on_file_changed, opt["id"])
+            widget.set_filename(folder)
         elif opt["type"] == "select":
             self.lookup_table[opt["id"]] = {}
             widget = Gtk.ComboBoxText.new()
@@ -504,8 +474,8 @@ class ConfigurationWindow(Gtk.Window):
             else:
                 current = self.get_string(opt['id'], '')
 
-            widget.set_active_id(current)
             widget.connect("changed", self.on_select_changed, opt["id"])
+            widget.set_active_id(current)
         elif opt["type"] == "slider":
             prefs = get_slider_prefs([opt["default"], opt["low"], opt["high"]])
             adj = Gtk.Adjustment(value=opt["default"], lower=opt["low"], upper=opt["high"],
@@ -524,8 +494,8 @@ class ConfigurationWindow(Gtk.Window):
             else:
                 value = self.get_double(opt['id'], opt['default'])
 
-            adj.set_value(value)
             widget.connect("value-changed", self.on_double_changed, opt["id"])
+            adj.set_value(value)
         elif opt["type"] == "spinbutton":
             widget = Gtk.SpinButton.new_with_range(opt["low"], opt["high"], 1)
 
@@ -535,13 +505,13 @@ class ConfigurationWindow(Gtk.Window):
             else:
                 value = self.get_int(opt['id'], opt['default'])
 
-            widget.set_value(value)
             widget.connect("value-changed", self.on_int_changed, opt["id"])
+            widget.set_value(value)
         elif opt["type"] == "color":
             widget = Gtk.ColorButton.new()
             color = self.get_string(opt["id"], "#000000")
-            widget.set_rgba(hex_to_rgba(color))
             widget.connect("color-set", self.on_color_changed, opt["id"])
+            widget.set_rgba(hex_to_rgba(color))
         else:
             print("Unrecognized type: %s" % opt["type"], file=sys.stderr)
             sys.exit(1)
@@ -669,7 +639,7 @@ class ConfigurationWindow(Gtk.Window):
                         except:
                             pass
                         argument = argument.replace("%", str(value))
-                    arguments.append(argument)
+                    arguments.append(GLib.shell_quote(argument))
         value = " ".join(arguments)
         self.xfconf_settings.set_string("arguments", value)
 
@@ -715,9 +685,6 @@ def get_filename(theme):
             if os.path.exists(cfg):
                 return cfg
 
-    if theme == "xfce-blank":
-        return ""
-
     return None
 
 
@@ -784,7 +751,7 @@ if __name__ == "__main__":
 
     if fname.endswith(".xml"):
         obj = XmlScreensaverSettings(saver)
-    elif fname.endswith(".desktop") or saver == "xfce-blank":
+    elif fname.endswith(".desktop"):
         obj = DesktopScreensaverSettings(saver)
     else:
         show_fatal(primary, _("Unrecognized file type: %s") % fname)
